zabbix_export:
  version: '7.0'
  template_groups:
    - uuid: a571c0d144b14fd4a87a9d9b2aa9fcd6
      name: Templates/Applications
  templates:
    - uuid: a7f0c853c6634b1dacaaf43c2a0d9375
      template: 'Jira Data Center by JMX'
      name: 'Jira Data Center by JMX'
      description: |
        This template is used for monitoring Jira Data Center health. It is designed for standalone operation for on-premises Jira installations.
        
        This template uses a single data source, JMX, which requires JMX RMI setup of your Jira application and Java Gateway setup on the Zabbix side.
        If you need "Garbage collector" and "Web server" monitoring, add "Generic Java JMX" and "Apache Tomcat by JMX" templates on the same host.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback
        
        Setup:
          Metrics are collected by JMX.
          0. Deploy the Zabbix Java Gateway component ([instructions](https://www.zabbix.com/documentation/7.0/manual/concepts/java)).
          1. Enable and configure JMX access to Jira Data Center. See documentation for [instructions](https://confluence.atlassian.com/adminjiraserver/live-monitoring-using-the-jmx-interface-939707304.html).
          2. Assign the "Jira Data Center by JMX" template to the host with a JMX interface.
          2. If your Jira installation requires authentication for JMX, set the values in the host macros `{$JMX.USERNAME}` and `{$JMX.PASSWORD}`.
          3. (Optional) Set custom macro values and add macros with context for specific metrics following the macro description.
          4. (Optional) Assign the "Generic Java JMX" template for garbage collector monitoring.
          5. (Optional) Assign the "Apache Tomcat by JMX" template for web server monitoring.
        
        tested_on:
          - Jira Data Center 9.14.1
          - Jira Data Center 9.12.4
        
        Generated by official Zabbix template tool "Templator"
      vendor:
        name: Zabbix
        version: 7.0-0
      groups:
        - name: Templates/Applications
      items:
        - uuid: 27334384618d4b2f91d700b188463a56
          name: 'License: Users: Get'
          type: JMX
          key: 'jmx.discovery[attributes,"com.atlassian.jira:type=jira.license"]'
          history: '0'
          value_type: TEXT
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'License data for the discovery rule.'
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var data = JSON.parse(value).data;
                  var result = {};
                  
                  data.forEach(function(item) {
                  	var attributes = item["{#JMXATTR}"].split(".");
                  	var license = attributes[0].replace("jira-","");
                  	var property = attributes.slice(1).join('_');
                  	if (!result[license]) {
                  		result[license] = {'properties': {} };
                  	}
                  
                  	result[license]['properties'][property] = item["{#JMXVALUE}"];
                  });
                  
                  return JSON.stringify(result);
                  
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: license
            - tag: component
              value: raw
        - uuid: 11a89b91831b4b5d899bff63ba935cbb
          name: 'DB: Connections: Limit'
          type: JMX
          key: 'jmx["com.atlassian.jira:name=BasicDataSource,connectionpool=connections",MaxTotal]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'Total allowed database connection count.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: database
        - uuid: f064dbd8781848c09184fb83a3a46097
          name: 'DB: Connections: Active'
          type: JMX
          key: 'jmx["com.atlassian.jira:name=BasicDataSource,connectionpool=connections",NumActive]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'Active database connection count.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: database
        - uuid: 2928e1e3b68940938a0b107eb5d72b95
          name: 'DB: Reads'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=db.reads",invocation\.count]'
          value_type: FLOAT
          units: rps
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: |
            Database read operations from Jira per second.
            Units: rps - read operations per second.
          preprocessing:
            - type: CHANGE_PER_SECOND
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: database
        - uuid: ad5c16fa48864dc6b625a23f95ecf07a
          name: 'DB: Writes'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=db.writes",invocation\.count]'
          value_type: FLOAT
          units: wps
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: |
            Database write operations from Jira per second.
            Units: wps - write operations per second.
          preprocessing:
            - type: CHANGE_PER_SECOND
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: database
        - uuid: 942556b043734986a2c5e261e97d5b1c
          name: 'Entity: Attachments'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=entity.attachments.total",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The number of attachments.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: application
            - tag: component
              value: entity
        - uuid: 7aa003c53cb14555a88ee02e804ca45f
          name: 'Entity: Components'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=entity.components.total",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The number of components.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: application
        - uuid: 8ddf2cb59bb44d8a8fe7f2ca9e44ad20
          name: 'Entity: Custom fields'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=entity.customfields.total",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The number of custom fields.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: application
        - uuid: 2c8d303953ed44b6815129a6a77ee5c6
          name: 'Entity: Filters'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=entity.filters.total",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The number of filters.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: application
        - uuid: 5d9a669481ab448eb5c9e0b64f3517b0
          name: 'Entity: Issues'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=entity.issues.total",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The number of issues.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: application
            - tag: component
              value: entity
            - tag: component
              value: issue
        - uuid: b6a8a8ed8a9242858560b0743cc955aa
          name: 'Entity: Versions created'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=entity.versions.total",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The number of versions created.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: application
        - uuid: 2152f7eb0bff4c9888e131634b770673
          name: 'Issue: Created per minute'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=issue.created.count",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'Issues created per minute.'
          preprocessing:
            - type: SIMPLE_CHANGE
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: application
            - tag: component
              value: issue
        - uuid: 25fdfd0e3dce4d95ac2cdaed41ba5fb6
          name: 'Issue: Search per minute'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=issue.search.count",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'Issue searches performed per minute.'
          preprocessing:
            - type: SIMPLE_CHANGE
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: application
            - tag: component
              value: issue
        - uuid: 060d5f5ccf3a4ab197e4b95d9eb88b17
          name: 'Issue: Updates per minute'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=issue.updated.count",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'Issue updates performed per minute.'
          preprocessing:
            - type: SIMPLE_CHANGE
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: application
            - tag: component
              value: issue
        - uuid: bb565c20d5ad4cf1a94aea5966ec12fa
          name: 'DB: Connections: Failed per minute'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=failures,name=counter",Count]'
          delay: 0;m0-59
          value_type: FLOAT
          units: fpm
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: |
            The count of database connection failures registered in one minute.
            Units: fpm - fails per minute.
          preprocessing:
            - type: SIMPLE_CHANGE
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: database
        - uuid: 8fb52b3e150a4f5fb84e8b527aaaf5a5
          name: 'DB: Connections: Latency'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=latency,name=value",Value]'
          value_type: FLOAT
          units: ms
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The latest measure of latency when querying the database.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: database
        - uuid: 2d22d7c78abe40b8a82fb70a8d1091d1
          name: 'DB: Pool: Connections: Active'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=pool,category03=numActive,name=value",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'Active connection count of the database pool.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: database
        - uuid: c18d258cdb8f420e8cb18a9e6e7c2bf8
          name: 'DB: Pool: Connections: Idle'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=pool,category03=numIdle,name=value",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'Idle connection count of the database pool.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: database
          triggers:
            - uuid: 5fd9800d1c3641c584e32106ea61e33d
              expression: 'min(/Jira Data Center by JMX/jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=pool,category03=numIdle,name=value",Value],5m)<=0'
              name: 'DB: Pool: Out of idle connections'
              opdata: 'Idle connections: {ITEM.LASTVALUE1}'
              priority: WARNING
              description: 'Fires when out of idle connections in database pool for 5 minutes.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: performance
        - uuid: fc7870021dc04bf499db8834be67987e
          name: 'DB: Connections: State'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=state,name=value",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The state of the database connection.'
          valuemap:
            name: 'Connection availability'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: database
          triggers:
            - uuid: 524b7cb0ac9940ad80e11f1c93f1d7df
              expression: 'max(/Jira Data Center by JMX/jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=state,name=value",Value],3m)=0'
              name: 'DB: Connection lost'
              opdata: 'Connection state: {ITEM.LASTVALUE1}'
              priority: AVERAGE
              description: 'Database connection lost'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: availability
        - uuid: 25d810c7fd5e4116a8e2323b7a2537a0
          name: 'HTTP: Pool: Connections: Active'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=http,category01=connection,category02=pool,category03=numActive,name=value",Value]'
          value_type: FLOAT
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The latest measure of the number of active connections in the HTTP connection pool.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: http
        - uuid: b244d220b7e24d48913f4e8e1b490732
          name: 'HTTP: Pool: Connections: Idle'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=http,category01=connection,category02=pool,category03=numIdle,name=value",Value]'
          value_type: FLOAT
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The latest measure of the number of idle connections in the HTTP connection pool.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: http
          triggers:
            - uuid: 7f0fde38527c4bb2930a1e57343c4422
              expression: 'min(/Jira Data Center by JMX/jmx["com.atlassian.jira:type=metrics,category00=http,category01=connection,category02=pool,category03=numIdle,name=value",Value],5m)<=0'
              name: 'HTTP: Pool: Out of idle connections'
              opdata: 'active {ITEM.LASTVALUE1} from {ITEM.LASTVALUE2}'
              priority: WARNING
              description: 'All available connections are utilized. It can cause outages for users as the system is unable to serve their requests.'
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: capacity
        - uuid: 195bc0648f6445bbbe205a5869383c68
          name: 'HTTP: Sessions: Active'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=http,category01=connection,category02=sessions,category03=active,name=value",Value]'
          value_type: FLOAT
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The latest measure of the number of active user sessions.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: http
        - uuid: 0d5a76f579284baf9eaa47180ed2c3fa
          name: 'HTTP: Requests per minute'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=http,category01=requests,name=value",Value]'
          value_type: FLOAT
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The latest measure of the total number of HTTP requests per minute.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: http
        - uuid: 7029cc0f375740c79790b410b92579a1
          name: 'Mail: Queue: Processing state'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=jobRunning,name=value",Value]'
          value_type: FLOAT
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The latest indicator of the state of a mail queue job.'
          valuemap:
            name: 'Mail sender'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: mail
        - uuid: 27f65a6cc7a147c2a95d3348db0cc9eb
          name: 'Mail: Sent per minute'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numEmailsSentPerMin,name=value",Value]'
          value_type: FLOAT
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The latest measure of the number of emails sent by the SMTP server per minute.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: mail
        - uuid: ec7e12f99490496c814e9000108ec8c9
          name: 'Mail: Queue: Error'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numErrors,name=value",Value]'
          value_type: FLOAT
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The latest measure of the number of items in an error mail queue.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: mail
          triggers:
            - uuid: f0940aecb8f24e788dae0e62c81a0c65
              expression: 'max(/Jira Data Center by JMX/jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numErrors,name=value",Value],5m)>0'
              name: 'Mail: Error queue contains one or more items'
              priority: WARNING
              description: |
                A mail queue attempts to resend items up to 10 times. If the operation fails for the 11th time, the items are put into an error mail queue.
                You can remove items from the error mail queue in one of the following ways:
                  - Manually clear the whole error queue.
                  - Manually resend all items from the error queue to a mail queue.
                You should pay attention to the cases where an error mail queue item gets back to an error mail queue after you resend the items manually. These cases might indicate permanent performance issues.
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: availability
        - uuid: 67789113243b4689af58e42d0a127878
          name: 'Mail: Queue'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numItems,name=value",Value]'
          value_type: FLOAT
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The latest measure of the number of items in a mail queue.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: mail
          triggers:
            - uuid: 6fc20e23f96f4bf8a856d1c86679cbd5
              expression: 'min(/Jira Data Center by JMX/jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numItems,name=value",Value],30m)>0'
              name: 'Mail: Queue: Doesn’t empty over an extended period'
              priority: WARNING
              description: 'Might indicate SMTP performance or connection problems.'
              manual_close: 'YES'
              dependencies:
                - name: 'Mail: Queue job is not running'
                  expression: 'max(/Jira Data Center by JMX/jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=jobRunning,name=value",Value],15m)=0 and min(/Jira Data Center by JMX/jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numItems,name=value",Value],15m)>0'
              tags:
                - tag: scope
                  value: performance
        - uuid: 3d311c2e46af4c98b11f5f1a50b5318e
          name: 'Mail: Processed per minute'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numItemsProcessedPerMin,name=value",Value]'
          value_type: FLOAT
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The latest measure of the number of items processed by a mail queue per minute.'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: mail
        - uuid: 6a81cf33cc834115b352324a18355368
          name: 'Quicksearch: Concurrent searches'
          type: JMX
          key: 'jmx["com.atlassian.jira:type=quicksearch.concurrent.search",Value]'
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          description: 'The number of concurrent searches that are being performed in real-time by using the quick search.'
          preprocessing:
            - type: SIMPLE_CHANGE
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
          tags:
            - tag: component
              value: application
      discovery_rules:
        - uuid: 6b671426094e4268b48f51eb97ddd8bf
          name: 'Storage discovery'
          type: JMX
          key: 'jmx.discovery[beans,"com.atlassian.jira:type=metrics,category00=home,category01=*,category02=write,category03=latency,*,name=value"]'
          delay: 1h
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          filter:
            evaltype: AND
            conditions:
              - macro: '{#JMXCATEGORY01}'
                value: '{$JIRA_DC.LLD.FILTER.MATCHES.HOMEFOLDERS}'
              - macro: '{#JMXCATEGORY01}'
                value: '{$JIRA_DC.LLD.FILTER.NOT.MATCHES.HOMEFOLDERS}'
                operator: NOT_MATCHES_REGEX
          description: 'Discovery of the Jira storage metrics.'
          item_prototypes:
            - uuid: 933c9c8b11e848f88775ee9b54f8d292
              name: 'Storage [{#JMXCATEGORY01}]: Latency'
              type: JMX
              key: 'jmx["{#JMXOBJ}",Value]'
              delay: 15m
              value_type: FLOAT
              units: s
              username: '{$JMX.USER}'
              password: '{$JMX.PASSWORD}'
              description: 'The median latency of writing a small file (~30 bytes) to `{#JMXCATEGORY01}`.'
              preprocessing:
                - type: MULTIPLIER
                  parameters:
                    - '0.001'
              jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
              tags:
                - tag: component
                  value: storage
              trigger_prototypes:
                - uuid: 7aaf19b9466942f7a2f4aed1fb5d5973
                  expression: 'min(/Jira Data Center by JMX/jmx["{#JMXOBJ}",Value],5m)>{$JIRA_DC.STORAGE.LATENCY.WARN:"{#JMXCATEGORY01}"}'
                  name: 'Storage [{#JMXCATEGORY01}]: Slow performance'
                  event_name: 'Storage [{#JMXCATEGORY01}]: Slow performance (latency > {$JIRA_DC.STORAGE.LATENCY.WARN:"{#JMXCATEGORY01}"}s)'
                  opdata: 'Average latency: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Fires when latency grows above the threshold: `{$JIRA_DC.STORAGE.LATENCY.WARN:"{#JMXCATEGORY01}"}`s'
                  manual_close: 'YES'
                  tags:
                    - tag: scope
                      value: performance
          graph_prototypes:
            - uuid: 5f5f61fe9bc848be87789a8ac6e2fbb2
              name: 'Storage [{#JMXCATEGORY01}]: Latency'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'Jira Data Center by JMX'
                    key: 'jmx["{#JMXOBJ}",Value]'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
        - uuid: 886f8b2c518d4f3bb3d4441e29bf13fc
          name: ' Indexing latency discovery'
          type: JMX
          key: 'jmx.discovery[beans,"com.atlassian.jira:type=metrics,category00=indexing,name=*"]'
          delay: 1h
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          filter:
            evaltype: AND
            conditions:
              - macro: '{#JMXNAME}'
                value: '{$JIRA_DC.LLD.FILTER.MATCHES.INDEXING}'
              - macro: '{#JMXNAME}'
                value: '{$JIRA_DC.LLD.FILTER.NOT.MATCHES.INDEXING}'
                operator: NOT_MATCHES_REGEX
          description: 'Discovery of the Jira indexing metrics.'
          item_prototypes:
            - uuid: 2b02e3232de34ae9803f80ac94ade79c
              name: 'Indexing [{#JMXNAME}]: Latency'
              type: JMX
              key: 'jmx["com.atlassian.jira:type=metrics,category00=indexing,name={#JMXNAME}",Mean]'
              delay: 15m
              value_type: FLOAT
              units: s
              username: '{$JMX.USER}'
              password: '{$JMX.PASSWORD}'
              description: 'Average time spent on indexing operations.'
              preprocessing:
                - type: MULTIPLIER
                  parameters:
                    - '0.001'
              jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
              tags:
                - tag: component
                  value: indexing
              trigger_prototypes:
                - uuid: 73c679de66e941fcbabe54cb9807fcf4
                  expression: 'min(/Jira Data Center by JMX/jmx["com.atlassian.jira:type=metrics,category00=indexing,name={#JMXNAME}",Mean],5m)>{$JIRA_DC.INDEXING.LATENCY.WARN:"{#JMXNAME}"}'
                  name: 'Indexing [{#JMXNAME}]: Slow performance'
                  event_name: 'Indexing [{#JMXNAME}]: Slow performance (latency > {$JIRA_DC.INDEXING.LATENCY.WARN:"{#JMXNAME}"}s)'
                  opdata: 'Average latency: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Fires when latency grows above the threshold: `{$JIRA_DC.INDEXING.LATENCY.WARN:"{#JMXNAME}"}`s'
                  manual_close: 'YES'
                  tags:
                    - tag: scope
                      value: performance
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
        - uuid: 70db70727f824102b769a652713432ad
          name: ' Issue latency discovery'
          type: JMX
          key: 'jmx.discovery[beans,"com.atlassian.jira:type=metrics,category00=issue,name=*"]'
          delay: 1h
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          filter:
            evaltype: AND
            conditions:
              - macro: '{#JMXNAME}'
                value: '{$JIRA_DC.LLD.FILTER.MATCHES.ISSUE}'
              - macro: '{#JMXNAME}'
                value: '{$JIRA_DC.LLD.FILTER.NOT.MATCHES.ISSUE}'
                operator: NOT_MATCHES_REGEX
          description: 'Discovery of the Jira issue latency metrics.'
          item_prototypes:
            - uuid: da6d68fa14f24f58bcbe1157b9818321
              name: 'Issue [{#JMXNAME}]: Latency'
              type: JMX
              key: 'jmx["{#JMXOBJ}",Mean]'
              delay: 15m
              value_type: FLOAT
              units: s
              username: '{$JMX.USER}'
              password: '{$JMX.PASSWORD}'
              description: 'Average time spent on issue `{#JMXNAME}` operations.'
              preprocessing:
                - type: MULTIPLIER
                  parameters:
                    - '0.001'
              jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
              tags:
                - tag: component
                  value: issue
              trigger_prototypes:
                - uuid: 5df1f61ce5d24204bcef4b8f021ea98a
                  expression: 'min(/Jira Data Center by JMX/jmx["{#JMXOBJ}",Mean],5m)>{$JIRA_DC.ISSUE.LATENCY.WARN:"{#JMXNAME}"}'
                  name: 'Issue [{#JMXNAME}]: Slow operations'
                  event_name: 'Issue [{#JMXNAME}]: Slow operations (longer then {$JIRA_DC.ISSUE.LATENCY.WARN:"{#JMXNAME}"}s)'
                  opdata: 'Average latency: {ITEM.LASTVALUE1}'
                  priority: WARNING
                  description: 'Fires when latency grows above the threshold: `{$JIRA_DC.ISSUE.LATENCY.WARN:"{#JMXNAME}"}`s'
                  manual_close: 'YES'
                  tags:
                    - tag: scope
                      value: performance
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
        - uuid: 2bd3e8ce78f84ccba599137b0e0ab6a0
          name: 'Mail server discovery'
          type: JMX
          key: 'jmx.discovery[beans,"com.atlassian.jira:type=metrics,category00=mail,category01=*,category02=connection,category03=state,name=*"]'
          delay: 1h
          username: '{$JMX.USER}'
          password: '{$JMX.PASSWORD}'
          filter:
            evaltype: AND
            conditions:
              - macro: '{#JMXCATEGORY01}'
                value: '{$JIRA_DC.LLD.FILTER.MATCHES.MAIL}'
              - macro: '{#JMXCATEGORY01}'
                value: '{$JIRA_DC.LLD.FILTER.NOT.MATCHES.MAIL}'
                operator: NOT_MATCHES_REGEX
          description: 'Discovery of the Jira connected mail servers.'
          item_prototypes:
            - uuid: 5281bee6b829433a875c0e026d805206
              name: 'Mail [{#JMXCATEGORY01},{#JMXNAME}]: Connection state'
              type: JMX
              key: 'jmx["{#JMXOBJ}",Connected]'
              username: '{$JMX.USER}'
              password: '{$JMX.PASSWORD}'
              description: 'Shows connection state of Jira to discovered mail server: `{#JMXCATEGORY01}-{#JMXNAME}`'
              valuemap:
                name: 'Connection availability'
              preprocessing:
                - type: BOOL_TO_DECIMAL
              jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
              tags:
                - tag: component
                  value: mail
                - tag: mail
                  value: '{#JMXCATEGORY01}-{#JMXNAME}'
              trigger_prototypes:
                - uuid: a28f2598b457479299d4fbf917d8189d
                  expression: 'max(/Jira Data Center by JMX/jmx["{#JMXOBJ}",Connected],5m)=0'
                  name: 'Mail [{#JMXCATEGORY01}-{#JMXNAME}]: Server disconnected'
                  opdata: 'Server state: {ITEM.LASTVALUE1}'
                  priority: AVERAGE
                  description: 'Trigger is fired when discovered mail server `{#JMXCATEGORY01}-{#JMXNAME}` becomes unavailable'
                  manual_close: 'YES'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 949854436d6542f9a859a65cec20572d
              name: 'Mail [{#JMXCATEGORY01},{#JMXNAME}]: Failures per minute'
              type: JMX
              key: 'jmx["{#JMXOBJ}",TotalFailures]'
              username: '{$JMX.USER}'
              password: '{$JMX.PASSWORD}'
              description: 'Count of failed connections to discovered mail server `{#JMXCATEGORY01}-{#JMXNAME}` per minute'
              preprocessing:
                - type: SIMPLE_CHANGE
              jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
              tags:
                - tag: component
                  value: mail
                - tag: mail
                  value: '{#JMXCATEGORY01}-{#JMXNAME}'
          graph_prototypes:
            - uuid: f51ddde64f414715bb5074f96cee8768
              name: 'Mail [{#JMXCATEGORY01},{#JMXNAME}]: State and failures'
              graph_items:
                - drawtype: FILLED_REGION
                  color: 199C0D
                  item:
                    host: 'Jira Data Center by JMX'
                    key: 'jmx["{#JMXOBJ}",Connected]'
                - sortorder: '1'
                  drawtype: BOLD_LINE
                  color: F63100
                  yaxisside: RIGHT
                  item:
                    host: 'Jira Data Center by JMX'
                    key: 'jmx["{#JMXOBJ}",TotalFailures]'
          jmx_endpoint: 'service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi'
        - uuid: 750f1986954f4cfda847bc66ecbfd910
          name: ' License discovery'
          type: DEPENDENT
          key: jmx.license.discovery
          filter:
            evaltype: AND
            conditions:
              - macro: '{#LICENSE.TYPE}'
                value: '{$JIRA_DC.LLD.FILTER.MATCHES.LICENSE}'
              - macro: '{#LICENSE.TYPE}'
                value: '{$JIRA_DC.LLD.FILTER.NOT.MATCHES.LICENSE}'
                operator: NOT_MATCHES_REGEX
          description: 'Discovery of the Jira licenses.'
          item_prototypes:
            - uuid: e2f1224ac6de4a24a50bf6b4356fdd25
              name: 'License [{#LICENSE.TYPE}]: Users: Current'
              type: DEPENDENT
              key: 'jmx.license.get.user.current["{#LICENSE.TYPE}"]'
              value_type: FLOAT
              description: 'Current user count for `{#LICENSE.TYPE}`.'
              valuemap:
                name: 'Limit mapping'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.{#LICENSE.TYPE}.properties.current_user_count'
              master_item:
                key: 'jmx.discovery[attributes,"com.atlassian.jira:type=jira.license"]'
              tags:
                - tag: component
                  value: application
                - tag: component
                  value: license
                - tag: license
                  value: '{#LICENSE.TYPE}'
            - uuid: 77e789c5d8484367997f45ce24b65cd9
              name: 'License [{#LICENSE.TYPE}]: Users: Maximum'
              type: DEPENDENT
              key: 'jmx.license.get.user.max["{#LICENSE.TYPE}"]'
              value_type: FLOAT
              description: |
                User count limit for `{#LICENSE.TYPE}`.
                `-1` = No limits for the license type.
              valuemap:
                name: 'Limit mapping'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.{#LICENSE.TYPE}.properties.max_user_count'
              master_item:
                key: 'jmx.discovery[attributes,"com.atlassian.jira:type=jira.license"]'
              tags:
                - tag: component
                  value: application
                - tag: component
                  value: license
                - tag: license
                  value: '{#LICENSE.TYPE}'
          trigger_prototypes:
            - uuid: 26439a9cf50f4dfea02e5c763feee50c
              expression: 'last(/Jira Data Center by JMX/jmx.license.get.user.max["{#LICENSE.TYPE}"])>=0 * (100*last(/Jira Data Center by JMX/jmx.license.get.user.current["{#LICENSE.TYPE}"])/last(/Jira Data Center by JMX/jmx.license.get.user.max["{#LICENSE.TYPE}"])>{$JIRA_DC.LICENSE.USER.CAPACITY.WARN:"{#LICENSE.TYPE}"})'
              name: 'License [{#LICENSE.TYPE}]: Low user capacity'
              event_name: 'License [{#LICENSE.TYPE}]: Low user capacity (created > {$JIRA_DC.LICENSE.USER.CAPACITY.WARN:"{#LICENSE.TYPE}"}%)'
              opdata: 'created {ITEM.LASTVALUE1} from {ITEM.LASTVALUE2}'
              priority: WARNING
              description: 'Fires when relative user quantity grows above the threshold: `{$JIRA_DC.LICENSE.USER.CAPACITY.WARN:"{#LICENSE.TYPE}"}`%'
              manual_close: 'YES'
              dependencies:
                - name: 'License [{#LICENSE.TYPE}]: User count reached the limit'
                  expression: 'last(/Jira Data Center by JMX/jmx.license.get.user.max["{#LICENSE.TYPE}"])>=0 * ((last(/Jira Data Center by JMX/jmx.license.get.user.max["{#LICENSE.TYPE}"])-last(/Jira Data Center by JMX/jmx.license.get.user.current["{#LICENSE.TYPE}"]))<=0)'
              tags:
                - tag: scope
                  value: capacity
            - uuid: 62e93342b6a64b999d485eab28c55bf1
              expression: 'last(/Jira Data Center by JMX/jmx.license.get.user.max["{#LICENSE.TYPE}"])>=0 * ((last(/Jira Data Center by JMX/jmx.license.get.user.max["{#LICENSE.TYPE}"])-last(/Jira Data Center by JMX/jmx.license.get.user.current["{#LICENSE.TYPE}"]))<=0)'
              name: 'License [{#LICENSE.TYPE}]: User count reached the limit'
              opdata: 'created {ITEM.LASTVALUE1} from {ITEM.LASTVALUE2}'
              priority: AVERAGE
              description: |
                Fires when user quantity reaches the limit.
                It won't fire if the limit is disabled (set to `-1`).
              manual_close: 'YES'
              tags:
                - tag: scope
                  value: capacity
          graph_prototypes:
            - uuid: c79af894d8b944f6bbedf86dfe1a5e84
              name: 'License [{#LICENSE.TYPE}]: Users'
              ymin_type_1: FIXED
              graph_items:
                - drawtype: FILLED_REGION
                  color: F63100
                  item:
                    host: 'Jira Data Center by JMX'
                    key: 'jmx.license.get.user.current["{#LICENSE.TYPE}"]'
                - sortorder: '1'
                  drawtype: FILLED_REGION
                  color: 199C0D
                  item:
                    host: 'Jira Data Center by JMX'
                    key: 'jmx.license.get.user.max["{#LICENSE.TYPE}"]'
          master_item:
            key: 'jmx.discovery[attributes,"com.atlassian.jira:type=jira.license"]'
          lld_macro_paths:
            - lld_macro: '{#LICENSE.PROPERTIES}'
              path: $.properties
            - lld_macro: '{#LICENSE.TYPE}'
              path: $.license
          preprocessing:
            - type: JAVASCRIPT
              parameters:
                - |
                  var data = JSON.parse(value);
                  var lld_form = [];
                  
                  for (var key in data) {
                  	lld_form.push({"license": key});
                  }
                  return JSON.stringify(lld_form);
                  
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
      tags:
        - tag: class
          value: software
        - tag: target
          value: jira-datacenter
      macros:
        - macro: '{$JIRA_DC.DB.CONNECTION.USAGE.WARN}'
          value: '80'
          description: 'Warning threshold for database connections usage (%).'
        - macro: '{$JIRA_DC.INDEXING.LATENCY.WARN}'
          value: '5'
          description: 'Warning threshold for indexing operation latency (in seconds).'
        - macro: '{$JIRA_DC.ISSUE.LATENCY.WARN}'
          value: '5'
          description: 'Warning threshold for issue operation latency (in seconds).'
        - macro: '{$JIRA_DC.LICENSE.USER.CAPACITY.WARN}'
          value: '80'
          description: 'User capacity warning threshold (%).'
        - macro: '{$JIRA_DC.LLD.FILTER.MATCHES.HOMEFOLDERS}'
          value: local|share
          description: 'Used for storage metric discovery.'
        - macro: '{$JIRA_DC.LLD.FILTER.MATCHES.INDEXING}'
          value: '.*'
          description: 'Used for indexing metric discovery.'
        - macro: '{$JIRA_DC.LLD.FILTER.MATCHES.ISSUE}'
          value: '.*'
          description: 'Used for issue discovery.'
        - macro: '{$JIRA_DC.LLD.FILTER.MATCHES.LICENSE}'
          value: '.*'
          description: 'Used for license discovery.'
        - macro: '{$JIRA_DC.LLD.FILTER.MATCHES.MAIL}'
          value: '.*'
          description: 'Used for mail server connection metric discovery.'
        - macro: '{$JIRA_DC.LLD.FILTER.NOT.MATCHES.HOMEFOLDERS}'
          value: 'NO MATCH'
          description: 'Used for storage metric discovery.'
        - macro: '{$JIRA_DC.LLD.FILTER.NOT.MATCHES.INDEXING}'
          value: 'NO MATCH'
          description: 'Used for indexing metric discovery.'
        - macro: '{$JIRA_DC.LLD.FILTER.NOT.MATCHES.ISSUE}'
          value: 'NO MATCH'
          description: 'Used for issue discovery.'
        - macro: '{$JIRA_DC.LLD.FILTER.NOT.MATCHES.LICENSE}'
          value: 'NO MATCH'
          description: 'Used for license discovery.'
        - macro: '{$JIRA_DC.LLD.FILTER.NOT.MATCHES.MAIL}'
          value: 'NO MATCH'
          description: 'Used for mail server connection metric discovery.'
        - macro: '{$JIRA_DC.STORAGE.LATENCY.WARN}'
          value: '5'
          description: 'Warning threshold for storage write operation latency (in seconds).'
        - macro: '{$JMX.PASSWORD}'
          type: SECRET_TEXT
          description: 'Password for JMX.'
        - macro: '{$JMX.USER}'
          description: 'User for JMX.'
      dashboards:
        - uuid: 0917c28fa1874a088f03a15e60c96c57
          name: 'Jira: Data Center'
          pages:
            - name: Application
              widgets:
                - type: item
                  name: 'Jira: Issue count'
                  width: '12'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=entity.issues.total",Value]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: svggraph
                  name: 'Jira: Issue: Operations per minute'
                  'y': '3'
                  width: '24'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 00FF00
                    - type: STRING
                      name: ds.0.color.1
                      value: 0000FF
                    - type: STRING
                      name: ds.0.color.2
                      value: FFBF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=issue.created.count",Value]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=issue.updated.count",Value]'
                    - type: ITEM
                      name: ds.0.itemids.2
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=issue.search.count",Value]'
                    - type: INTEGER
                      name: legend_lines
                      value: '3'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAEAA
                - type: item
                  name: 'Jira: Attachment count'
                  x: '12'
                  width: '12'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=entity.attachments.total",Value]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: 'Jira: Filter count'
                  x: '24'
                  width: '12'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=entity.filters.total",Value]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: svggraph
                  name: 'Jira: Issue: Latency'
                  x: '24'
                  'y': '3'
                  width: '24'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: ds.0.aggregate_function
                      value: '3'
                    - type: STRING
                      name: ds.0.aggregate_interval
                      value: 30m
                    - type: STRING
                      name: ds.0.color
                      value: FFBF00
                    - type: STRING
                      name: ds.0.items.0
                      value: 'Issue [*]: Latency'
                    - type: INTEGER
                      name: ds.0.type
                      value: '3'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '5'
                    - type: STRING
                      name: or.0.color
                      value: 00FF00
                    - type: STRING
                      name: or.0.items.0
                      value: '*Create*'
                    - type: STRING
                      name: or.1.color
                      value: 0000FF
                    - type: STRING
                      name: or.1.items.0
                      value: '*Update*'
                    - type: STRING
                      name: or.2.color
                      value: FF0000
                    - type: STRING
                      name: or.2.items.0
                      value: '*Delete*'
                    - type: STRING
                      name: or.3.color
                      value: FFBF00
                    - type: STRING
                      name: or.3.items.0
                      value: '*ReIndex*'
                    - type: STRING
                      name: or.4.color
                      value: 4000FF
                    - type: STRING
                      name: or.4.items.0
                      value: '*DeIndex*'
                    - type: STRING
                      name: reference
                      value: AAEAC
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: item
                  name: 'Jira: Component count'
                  x: '36'
                  width: '12'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=entity.components.total",Value]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: item
                  name: 'Jira: Custom field count'
                  x: '48'
                  width: '12'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=entity.customfields.total",Value]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: svggraph
                  name: 'Jira: Quicksearch: Concurrent searches'
                  x: '48'
                  'y': '3'
                  width: '24'
                  height: '6'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FFBF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=quicksearch.concurrent.search",Value]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAEAB
                - type: item
                  name: 'Jira: Version count'
                  x: '60'
                  width: '12'
                  height: '3'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=entity.versions.total",Value]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
            - name: Database
              widgets:
                - type: item
                  name: 'Jira: DB: Connection state '
                  width: '24'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=state,name=value",Value]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: STRING
                      name: thresholds.0.color
                      value: 4CAF50
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '1'
                    - type: STRING
                      name: thresholds.1.color
                      value: EF5350
                    - type: STRING
                      name: thresholds.1.threshold
                      value: '0'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: svggraph
                  name: 'Jira: DB: Connections: Latency'
                  'y': '5'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FF0000
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=latency,name=value",Value]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Jira: DB: Connections'
                  'y': '10'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FF0000
                    - type: STRING
                      name: ds.0.color.1
                      value: 00FF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:name=BasicDataSource,connectionpool=connections",NumActive]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:name=BasicDataSource,connectionpool=connections",MaxTotal]'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAFA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Jira: DB: Writes per second'
                  x: '24'
                  width: '24'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 00BFFF
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=db.writes",invocation\.count]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAE
                - type: svggraph
                  name: 'Jira: DB: Pool connections'
                  x: '36'
                  'y': '5'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FF0000
                    - type: STRING
                      name: ds.0.color.1
                      value: 00FF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=pool,category03=numActive,name=value",Value]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=pool,category03=numIdle,name=value",Value]'
                    - type: INTEGER
                      name: ds.0.stacked
                      value: '1'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAB
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Jira: DB: Connections: Failed per minute'
                  x: '36'
                  'y': '10'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FF0000
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=db,category01=connection,category02=failures,name=counter",Count]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAFE
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Jira: DB: Reads per second'
                  x: '48'
                  width: '24'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FFBF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=db.reads",invocation\.count]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AAAAF
            - name: HTTP
              widgets:
                - type: svggraph
                  name: 'Jira: HTTP: Sessions: Active'
                  width: '24'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FFBF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=http,category01=connection,category02=sessions,category03=active,name=value",Value]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AABAA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Jira: HTTP: Pool connections'
                  x: '24'
                  width: '24'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FF0000
                    - type: STRING
                      name: ds.0.color.1
                      value: 00FF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=http,category01=connection,category02=pool,category03=numActive,name=value",Value]'
                    - type: ITEM
                      name: ds.0.itemids.1
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=http,category01=connection,category02=pool,category03=numIdle,name=value",Value]'
                    - type: INTEGER
                      name: ds.0.stacked
                      value: '1'
                    - type: INTEGER
                      name: legend_columns
                      value: '1'
                    - type: INTEGER
                      name: legend_lines
                      value: '2'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AABAB
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Jira: HTTP: Requests per minute'
                  x: '48'
                  width: '24'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FFBF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=http,category01=requests,name=value",Value]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AABAA
            - name: Mail
              widgets:
                - type: item
                  name: 'Jira: Mail: Queue: Processing state '
                  width: '24'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: decimal_places
                      value: '0'
                    - type: ITEM
                      name: itemid.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=jobRunning,name=value",Value]'
                    - type: INTEGER
                      name: show.0
                      value: '2'
                    - type: INTEGER
                      name: show.1
                      value: '3'
                    - type: INTEGER
                      name: show.2
                      value: '4'
                    - type: STRING
                      name: thresholds.0.color
                      value: FFBF00
                    - type: STRING
                      name: thresholds.0.threshold
                      value: '1'
                    - type: INTEGER
                      name: time_h_pos
                      value: '2'
                    - type: INTEGER
                      name: time_size
                      value: '9'
                    - type: INTEGER
                      name: time_v_pos
                      value: '2'
                    - type: INTEGER
                      name: value_size
                      value: '25'
                - type: svggraph
                  name: 'Jira: Mail: Processed per minute'
                  'y': '5'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FFBF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numItemsProcessedPerMin,name=value",Value]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AADAE
                - type: graphprototype
                  name: 'Jira: Mail server discovery'
                  'y': '10'
                  width: '72'
                  height: '5'
                  fields:
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Jira Data Center by JMX'
                        name: 'Mail [{#JMXCATEGORY01},{#JMXNAME}]: State and failures'
                    - type: STRING
                      name: reference
                      value: AADFA
                - type: svggraph
                  name: 'Jira: Mail: Queue'
                  x: '24'
                  width: '24'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FFBF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numItems,name=value",Value]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AADAA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
                - type: svggraph
                  name: 'Jira: Mail: Sent per minute'
                  x: '36'
                  'y': '5'
                  width: '36'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: 00FF00
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numEmailsSentPerMin,name=value",Value]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AADAF
                - type: svggraph
                  name: 'Jira: Mail: Queue: Error'
                  x: '48'
                  width: '24'
                  height: '5'
                  fields:
                    - type: STRING
                      name: ds.0.color.0
                      value: FF0000
                    - type: INTEGER
                      name: ds.0.dataset_type
                      value: '0'
                    - type: ITEM
                      name: ds.0.itemids.0
                      value:
                        host: 'Jira Data Center by JMX'
                        key: 'jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numErrors,name=value",Value]'
                    - type: INTEGER
                      name: legend_statistic
                      value: '1'
                    - type: STRING
                      name: reference
                      value: AADAC
                    - type: INTEGER
                      name: show_problems
                      value: '1'
            - name: License
              widgets:
                - type: honeycomb
                  name: 'Jira: License: Users'
                  width: '72'
                  height: '5'
                  fields:
                    - type: STRING
                      name: items.0
                      value: 'License [*]: Users: *'
                    - type: STRING
                      name: primary_label
                      value: '{{ITEM.NAME}.regsub("\[(.*)]: Users: (.*)","\1: \2")}'
                    - type: STRING
                      name: reference
                      value: BAAAA
                    - type: INTEGER
                      name: secondary_label_decimal_places
                      value: '0'
            - name: Storage
              widgets:
                - type: graphprototype
                  name: 'Jira: Storage latency'
                  width: '72'
                  height: '5'
                  fields:
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'Jira Data Center by JMX'
                        name: 'Storage [{#JMXCATEGORY01}]: Latency'
                    - type: STRING
                      name: reference
                      value: AAFAA
            - name: Indexing
              widgets:
                - type: svggraph
                  name: 'Jira: Indexing: Latency'
                  width: '72'
                  height: '6'
                  fields:
                    - type: INTEGER
                      name: ds.0.aggregate_function
                      value: '3'
                    - type: STRING
                      name: ds.0.aggregate_interval
                      value: 30m
                    - type: STRING
                      name: ds.0.color
                      value: FFBF00
                    - type: STRING
                      name: ds.0.items.0
                      value: 'Indexing [*]: Latency'
                    - type: INTEGER
                      name: ds.0.type
                      value: '3'
                    - type: INTEGER
                      name: legend_columns
                      value: '2'
                    - type: INTEGER
                      name: legend_lines
                      value: '7'
                    - type: STRING
                      name: or.0.color
                      value: BF00FF
                    - type: STRING
                      name: or.0.items.0
                      value: '*CreateChangeHistoryDocument*'
                    - type: STRING
                      name: or.1.color
                      value: 0080FF
                    - type: STRING
                      name: or.1.items.0
                      value: '*CreateIssueDocumentBatch*'
                    - type: STRING
                      name: or.2.color
                      value: 00FFFF
                    - type: STRING
                      name: or.2.items.0
                      value: '*LuceneConditionalUpdateDocument*'
                    - type: STRING
                      name: or.3.color
                      value: 00FF00
                    - type: STRING
                      name: or.3.items.0
                      value: '*LuceneUpdateDocument*'
                    - type: STRING
                      name: or.4.color
                      value: FFFF00
                    - type: STRING
                      name: or.4.items.0
                      value: '*changehistoryAddSearchExtractors*'
                    - type: STRING
                      name: or.5.color
                      value: FF8000
                    - type: STRING
                      name: or.5.items.0
                      value: '*issueAddSearchExtractors*'
                    - type: STRING
                      name: or.6.color
                      value: CC6600
                    - type: STRING
                      name: or.6.items.0
                      value: '*CreateCommentDocument*'
                    - type: STRING
                      name: or.7.color
                      value: 4000FF
                    - type: STRING
                      name: or.7.items.0
                      value: '*IssueAddFieldIndexers*'
                    - type: STRING
                      name: or.8.color
                      value: FF0000
                    - type: STRING
                      name: or.8.items.0
                      value: '*LuceneDeleteDocument*'
                    - type: STRING
                      name: or.9.color
                      value: '666699'
                    - type: STRING
                      name: or.9.items.0
                      value: '*WaitForLucene*'
                    - type: STRING
                      name: or.10.color
                      value: FFBF00
                    - type: STRING
                      name: or.10.items.0
                      value: '*commentAddSearchExtractors*'
                    - type: STRING
                      name: or.11.color
                      value: 00FFBF
                    - type: STRING
                      name: or.11.items.0
                      value: '*worklogAddSearchExtractors*'
                    - type: STRING
                      name: reference
                      value: ABAAA
                    - type: INTEGER
                      name: show_problems
                      value: '1'
      valuemaps:
        - uuid: 6d06a74d603f4ffd8540c8b87f910c7e
          name: 'Connection availability'
          mappings:
            - value: '0'
              newvalue: Down
            - value: '1'
              newvalue: Up
        - uuid: ae5cd12f5e3f4da7aab84db686771cb1
          name: 'Limit mapping'
          mappings:
            - value: '-1'
              newvalue: Limitless
        - uuid: c5e16a1b701e429e8eff56c598530d60
          name: 'Mail sender'
          mappings:
            - value: '0'
              newvalue: Inactive
            - value: '1'
              newvalue: Running
  triggers:
    - uuid: a91e17e5f510499eb6d0848703cf3df1
      expression: 'min(/Jira Data Center by JMX/jmx["com.atlassian.jira:name=BasicDataSource,connectionpool=connections",NumActive],5m)=last(/Jira Data Center by JMX/jmx["com.atlassian.jira:name=BasicDataSource,connectionpool=connections",MaxTotal])'
      name: 'DB: Connection limit reached'
      opdata: 'active {ITEM.LASTVALUE1} from {ITEM.LASTVALUE2}'
      priority: WARNING
      manual_close: 'YES'
      tags:
        - tag: scope
          value: performance
    - uuid: 8de58465caad4a188a1a84140ec9ebcf
      expression: '100*min(/Jira Data Center by JMX/jmx["com.atlassian.jira:name=BasicDataSource,connectionpool=connections",NumActive],5m)/last(/Jira Data Center by JMX/jmx["com.atlassian.jira:name=BasicDataSource,connectionpool=connections",MaxTotal])>{$JIRA_DC.DB.CONNECTION.USAGE.WARN}'
      name: 'DB: Connection usage is near the limit'
      event_name: 'DB: Connection usage is near the limit (above {$JIRA_DC.DB.CONNECTION.USAGE.WARN}%)'
      opdata: 'active {ITEM.LASTVALUE1} from {ITEM.LASTVALUE2}'
      priority: WARNING
      manual_close: 'YES'
      tags:
        - tag: scope
          value: performance
    - uuid: 7fc17e55907041c2a907310bd45f14be
      expression: 'max(/Jira Data Center by JMX/jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=jobRunning,name=value",Value],15m)=0 and min(/Jira Data Center by JMX/jmx["com.atlassian.jira:type=metrics,category00=mail,category01=queue,category02=numItems,name=value",Value],15m)>0'
      name: 'Mail: Queue job is not running'
      priority: AVERAGE
      description: |
        It should be running when its queue is not empty.
        Might indicate SMTP server connection problems.
      manual_close: 'YES'
      tags:
        - tag: scope
          value: availability
